macro_rules! trace_packet {
($($arg:tt)*) => { ... };
}Expand description
Writes a trace of the given communication packet or event if enable_tracing has been called.
macro_rules! trace_packet {
($($arg:tt)*) => { ... };
}Writes a trace of the given communication packet or event if enable_tracing has been called.