pub enum IngredientRangeInfo {
Coffee(u16, u16, u16),
Milk(u16, u16, u16),
HotWater(u16, u16, u16),
Taste(EcamBeverageTaste),
Temperature(EcamTemperature),
Accessory(EcamAccessory),
Inversion(bool, bool),
Brew2(bool, bool),
}Expand description
The processed ingredients from the raw ECAM responses. Some ingredients are omitted as they are not useful for brewing.
This could be done with the raw RecipeMinMaxInfo, but an older attempt at this code tried that and it became a
fairly decent mess.
Variants
Coffee(u16, u16, u16)
Milk(u16, u16, u16)
HotWater(u16, u16, u16)
Taste(EcamBeverageTaste)
Temperature(EcamTemperature)
Accessory(EcamAccessory)
Inversion(bool, bool)
Brew2(bool, bool)
Implementations
Sourceimpl IngredientRangeInfo
impl IngredientRangeInfo
Sourcepub fn new(
ingredient: EcamIngredients,
r1: Option<RecipeInfo<u16>>,
r2: Option<RecipeMinMaxInfo>,
) -> Result<Option<Self>, String>
pub fn new( ingredient: EcamIngredients, r1: Option<RecipeInfo<u16>>, r2: Option<RecipeMinMaxInfo>, ) -> Result<Option<Self>, String>
Attempts to parse a RecipeInfo and RecipeMinMaxInfo into an IngredientRangeInfo. If this fails, it returns a string with
a human-readable error.
pub fn to_default(&self) -> BrewIngredientInfo
pub fn to_arg_string(&self) -> Option<String>
pub fn ingredient(&self) -> EcamIngredients